@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -32,9 +32,10 @@ except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.cloud.texttospeech_v1.types import cloud_tts
-from .transports.base import TextToSpeechTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import TextToSpeechGrpcAsyncIOTransport
+
 from .client import TextToSpeechClient
+from .transports.base import DEFAULT_CLIENT_INFO, TextToSpeechTransport
+from .transports.grpc_asyncio import TextToSpeechGrpcAsyncIOTransport
 
 
 class TextToSpeechAsyncClient:
@@ -212,16 +213,16 @@ class TextToSpeechAsyncClient:
 
             from google.cloud import texttospeech_v1
 
-            def sample_list_voices():
+            async def sample_list_voices():
                 # Create a client
-                client = texttospeech_v1.TextToSpeechClient()
+                client = texttospeech_v1.TextToSpeechAsyncClient()
 
                 # Initialize request argument(s)
                 request = texttospeech_v1.ListVoicesRequest(
                 )
 
                 # Make the request
-                response = client.list_voices(request=request)
+                response = await client.list_voices(request=request)
 
                 # Handle the response
                 print(response)
@@ -282,7 +283,12 @@ class TextToSpeechAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -301,14 +307,13 @@ class TextToSpeechAsyncClient:
         r"""Synthesizes speech synchronously: receive results
         after all text input has been processed.
 
-
         .. code-block:: python
 
             from google.cloud import texttospeech_v1
 
-            def sample_synthesize_speech():
+            async def sample_synthesize_speech():
                 # Create a client
-                client = texttospeech_v1.TextToSpeechClient()
+                client = texttospeech_v1.TextToSpeechAsyncClient()
 
                 # Initialize request argument(s)
                 input = texttospeech_v1.SynthesisInput()
@@ -327,7 +332,7 @@ class TextToSpeechAsyncClient:
                 )
 
                 # Make the request
-                response = client.synthesize_speech(request=request)
+                response = await client.synthesize_speech(request=request)
 
                 # Handle the response
                 print(response)
@@ -399,7 +404,12 @@ class TextToSpeechAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
