@@ -15,15 +15,15 @@
 #
 import abc
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
-import pkg_resources
 
-import google.auth  # type: ignore
 import google.api_core
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 from google.cloud.texttospeech_v1beta1.types import cloud_tts
 
@@ -80,6 +80,7 @@ class TextToSpeechTransport(abc.ABC):
             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                 be used for service account credentials.
         """
+
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
         if ":" not in host:
             host += ":443"
@@ -121,19 +122,23 @@ class TextToSpeechTransport(abc.ABC):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
             self.list_voices: gapic_v1.method.wrap_method(
-                self.list_voices, default_timeout=None, client_info=client_info,
+                self.list_voices,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.synthesize_speech: gapic_v1.method.wrap_method(
-                self.synthesize_speech, default_timeout=None, client_info=client_info,
+                self.synthesize_speech,
+                default_timeout=None,
+                client_info=client_info,
             ),
         }
 
     def close(self):
         """Closes resources associated with the transport.
 
-       .. warning::
-            Only call this method if the transport is NOT shared
-            with other clients - this may cause errors in other clients!
+        .. warning::
+             Only call this method if the transport is NOT shared
+             with other clients - this may cause errors in other clients!
         """
         raise NotImplementedError()
 
@@ -158,5 +163,9 @@ class TextToSpeechTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def kind(self) -> str:
+        raise NotImplementedError()
+
 
 __all__ = ("TextToSpeechTransport",)
