@@ -14,31 +14,34 @@
 # limitations under the License.
 #
 import os
-import mock
 
-import grpc
-from grpc.experimental import aio
+# try/except added for compatibility with python < 3.8
+try:
+    from unittest import mock
+    from unittest.mock import AsyncMock
+except ImportError:
+    import mock
+
 import math
-import pytest
-from proto.marshal.rules.dates import DurationRule, TimestampRule
-
 
+from google.api_core import gapic_v1, grpc_helpers, grpc_helpers_async, path_template
 from google.api_core import client_options
 from google.api_core import exceptions as core_exceptions
-from google.api_core import gapic_v1
-from google.api_core import grpc_helpers
-from google.api_core import grpc_helpers_async
-from google.api_core import path_template
+import google.auth
 from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
+from google.oauth2 import service_account
+import grpc
+from grpc.experimental import aio
+from proto.marshal.rules.dates import DurationRule, TimestampRule
+import pytest
+
 from google.cloud.texttospeech_v1beta1.services.text_to_speech import (
     TextToSpeechAsyncClient,
+    TextToSpeechClient,
+    transports,
 )
-from google.cloud.texttospeech_v1beta1.services.text_to_speech import TextToSpeechClient
-from google.cloud.texttospeech_v1beta1.services.text_to_speech import transports
 from google.cloud.texttospeech_v1beta1.types import cloud_tts
-from google.oauth2 import service_account
-import google.auth
 
 
 def client_cert_source_callback():
@@ -82,19 +85,25 @@ def test__get_default_mtls_endpoint():
     assert TextToSpeechClient._get_default_mtls_endpoint(non_googleapi) == non_googleapi
 
 
-@pytest.mark.parametrize("client_class", [TextToSpeechClient, TextToSpeechAsyncClient,])
-def test_text_to_speech_client_from_service_account_info(client_class):
+@pytest.mark.parametrize(
+    "client_class,transport_name",
+    [
+        (TextToSpeechClient, "grpc"),
+        (TextToSpeechAsyncClient, "grpc_asyncio"),
+    ],
+)
+def test_text_to_speech_client_from_service_account_info(client_class, transport_name):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = client_class.from_service_account_info(info)
+        client = client_class.from_service_account_info(info, transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "texttospeech.googleapis.com:443"
+        assert client.transport._host == ("texttospeech.googleapis.com:443")
 
 
 @pytest.mark.parametrize(
@@ -122,22 +131,32 @@ def test_text_to_speech_client_service_account_always_use_jwt(
         use_jwt.assert_not_called()
 
 
-@pytest.mark.parametrize("client_class", [TextToSpeechClient, TextToSpeechAsyncClient,])
-def test_text_to_speech_client_from_service_account_file(client_class):
+@pytest.mark.parametrize(
+    "client_class,transport_name",
+    [
+        (TextToSpeechClient, "grpc"),
+        (TextToSpeechAsyncClient, "grpc_asyncio"),
+    ],
+)
+def test_text_to_speech_client_from_service_account_file(client_class, transport_name):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
-        client = client_class.from_service_account_file("dummy/file/path.json")
+        client = client_class.from_service_account_file(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        client = client_class.from_service_account_json("dummy/file/path.json")
+        client = client_class.from_service_account_json(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "texttospeech.googleapis.com:443"
+        assert client.transport._host == ("texttospeech.googleapis.com:443")
 
 
 def test_text_to_speech_client_get_transport_class():
@@ -477,7 +496,9 @@ def test_text_to_speech_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -615,10 +636,17 @@ def test_text_to_speech_client_create_channel_credentials_file(
         )
 
 
-@pytest.mark.parametrize("request_type", [cloud_tts.ListVoicesRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        cloud_tts.ListVoicesRequest,
+        dict,
+    ],
+)
 def test_list_voices(request_type, transport: str = "grpc"):
     client = TextToSpeechClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -644,7 +672,8 @@ def test_list_voices_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = TextToSpeechClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -660,7 +689,8 @@ async def test_list_voices_async(
     transport: str = "grpc_asyncio", request_type=cloud_tts.ListVoicesRequest
 ):
     client = TextToSpeechAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -690,7 +720,9 @@ async def test_list_voices_async_from_dict():
 
 
 def test_list_voices_flattened():
-    client = TextToSpeechClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = TextToSpeechClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.list_voices), "__call__") as call:
@@ -698,7 +730,9 @@ def test_list_voices_flattened():
         call.return_value = cloud_tts.ListVoicesResponse()
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
-        client.list_voices(language_code="language_code_value",)
+        client.list_voices(
+            language_code="language_code_value",
+        )
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -710,19 +744,24 @@ def test_list_voices_flattened():
 
 
 def test_list_voices_flattened_error():
-    client = TextToSpeechClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = TextToSpeechClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
         client.list_voices(
-            cloud_tts.ListVoicesRequest(), language_code="language_code_value",
+            cloud_tts.ListVoicesRequest(),
+            language_code="language_code_value",
         )
 
 
 @pytest.mark.asyncio
 async def test_list_voices_flattened_async():
-    client = TextToSpeechAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = TextToSpeechAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.list_voices), "__call__") as call:
@@ -734,7 +773,9 @@ async def test_list_voices_flattened_async():
         )
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
-        response = await client.list_voices(language_code="language_code_value",)
+        response = await client.list_voices(
+            language_code="language_code_value",
+        )
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -747,20 +788,30 @@ async def test_list_voices_flattened_async():
 
 @pytest.mark.asyncio
 async def test_list_voices_flattened_error_async():
-    client = TextToSpeechAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = TextToSpeechAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
         await client.list_voices(
-            cloud_tts.ListVoicesRequest(), language_code="language_code_value",
+            cloud_tts.ListVoicesRequest(),
+            language_code="language_code_value",
         )
 
 
-@pytest.mark.parametrize("request_type", [cloud_tts.SynthesizeSpeechRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        cloud_tts.SynthesizeSpeechRequest,
+        dict,
+    ],
+)
 def test_synthesize_speech(request_type, transport: str = "grpc"):
     client = TextToSpeechClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -791,7 +842,8 @@ def test_synthesize_speech_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = TextToSpeechClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -809,7 +861,8 @@ async def test_synthesize_speech_async(
     transport: str = "grpc_asyncio", request_type=cloud_tts.SynthesizeSpeechRequest
 ):
     client = TextToSpeechAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -822,7 +875,9 @@ async def test_synthesize_speech_async(
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
-            cloud_tts.SynthesizeSpeechResponse(audio_content=b"audio_content_blob",)
+            cloud_tts.SynthesizeSpeechResponse(
+                audio_content=b"audio_content_blob",
+            )
         )
         response = await client.synthesize_speech(request)
 
@@ -842,7 +897,9 @@ async def test_synthesize_speech_async_from_dict():
 
 
 def test_synthesize_speech_flattened():
-    client = TextToSpeechClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = TextToSpeechClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -878,7 +935,9 @@ def test_synthesize_speech_flattened():
 
 
 def test_synthesize_speech_flattened_error():
-    client = TextToSpeechClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = TextToSpeechClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -895,7 +954,9 @@ def test_synthesize_speech_flattened_error():
 
 @pytest.mark.asyncio
 async def test_synthesize_speech_flattened_async():
-    client = TextToSpeechAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = TextToSpeechAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -936,7 +997,9 @@ async def test_synthesize_speech_flattened_async():
 
 @pytest.mark.asyncio
 async def test_synthesize_speech_flattened_error_async():
-    client = TextToSpeechAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = TextToSpeechAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -958,7 +1021,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = TextToSpeechClient(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -978,7 +1042,10 @@ def test_credentials_transport_error():
     options = client_options.ClientOptions()
     options.api_key = "api_key"
     with pytest.raises(ValueError):
-        client = TextToSpeechClient(client_options=options, transport=transport,)
+        client = TextToSpeechClient(
+            client_options=options,
+            transport=transport,
+        )
 
     # It is an error to provide an api_key and a credential.
     options = mock.Mock()
@@ -994,7 +1061,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = TextToSpeechClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -1037,10 +1105,28 @@ def test_transport_adc(transport_class):
         adc.assert_called_once()
 
 
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+    ],
+)
+def test_transport_kind(transport_name):
+    transport = TextToSpeechClient.get_transport_class(transport_name)(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert transport.kind == transport_name
+
+
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = TextToSpeechClient(credentials=ga_credentials.AnonymousCredentials(),)
-    assert isinstance(client.transport, transports.TextToSpeechGrpcTransport,)
+    client = TextToSpeechClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert isinstance(
+        client.transport,
+        transports.TextToSpeechGrpcTransport,
+    )
 
 
 def test_text_to_speech_base_transport_error():
@@ -1075,6 +1161,14 @@ def test_text_to_speech_base_transport():
     with pytest.raises(NotImplementedError):
         transport.close()
 
+    # Catch all for all remaining methods and properties
+    remainder = [
+        "kind",
+    ]
+    for r in remainder:
+        with pytest.raises(NotImplementedError):
+            getattr(transport, r)()
+
 
 def test_text_to_speech_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
@@ -1086,7 +1180,8 @@ def test_text_to_speech_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.TextToSpeechTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1216,24 +1311,40 @@ def test_text_to_speech_grpc_transport_client_cert_source_for_mtls(transport_cla
             )
 
 
-def test_text_to_speech_host_no_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_text_to_speech_host_no_port(transport_name):
     client = TextToSpeechClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="texttospeech.googleapis.com"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "texttospeech.googleapis.com:443"
+    assert client.transport._host == ("texttospeech.googleapis.com:443")
 
 
-def test_text_to_speech_host_with_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_text_to_speech_host_with_port(transport_name):
     client = TextToSpeechClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="texttospeech.googleapis.com:8000"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "texttospeech.googleapis.com:8000"
+    assert client.transport._host == ("texttospeech.googleapis.com:8000")
 
 
 def test_text_to_speech_grpc_transport_channel():
@@ -1241,7 +1352,8 @@ def test_text_to_speech_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.TextToSpeechGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1253,7 +1365,8 @@ def test_text_to_speech_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.TextToSpeechGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1357,7 +1470,9 @@ def test_model_path():
     location = "clam"
     model = "whelk"
     expected = "projects/{project}/locations/{location}/models/{model}".format(
-        project=project, location=location, model=model,
+        project=project,
+        location=location,
+        model=model,
     )
     actual = TextToSpeechClient.model_path(project, location, model)
     assert expected == actual
@@ -1398,7 +1513,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "winkle"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = TextToSpeechClient.common_folder_path(folder)
     assert expected == actual
 
@@ -1416,7 +1533,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "scallop"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = TextToSpeechClient.common_organization_path(organization)
     assert expected == actual
 
@@ -1434,7 +1553,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "squid"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = TextToSpeechClient.common_project_path(project)
     assert expected == actual
 
@@ -1454,7 +1575,8 @@ def test_common_location_path():
     project = "whelk"
     location = "octopus"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = TextToSpeechClient.common_location_path(project, location)
     assert expected == actual
@@ -1479,7 +1601,8 @@ def test_client_with_default_client_info():
         transports.TextToSpeechTransport, "_prep_wrapped_messages"
     ) as prep:
         client = TextToSpeechClient(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1488,7 +1611,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = TextToSpeechClient.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1496,7 +1620,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = TextToSpeechAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
